/*
*************
*************
********
******

UVA StatLab Workshop
Better Graphics with Stata
January 29, 2014

By: Brenton Peterson

Summary: This file reproduces, in order, all of the graphs created and presented in the StatLab workshop

Note: If reading in Notepad++, key changes to graph commands are highlighted in yellow; supplementary information is highlighted in blue

Note 2: We make use of several add-ons.  You'll need to do -findit- and install the scheme s1mono (-findit s1mono-), the coefplot package (-findit coefplot-)

******
********
*************
*************
*/

** Change working directory -- wherever you extracted the files **
cd "\Better Graphics in Stata"

use "county_2010.dta", clear


/* ** Before doing anything, take a look at the data with -browse- command
		
		-We have ~3000 observations, one for each county
		-Organized by state
		-Lots of social, economic and demographic data for each county
*/


** Set a scheme (a style, basically) for your graphs. To illustrate a few popular schemes, consider these three scatterplots **

set scheme s2color
twoway scatter poverty bach_deg   

set scheme tufte
twoway scatter poverty bach_deg

set scheme vg_rose
twoway scatter poverty bach_deg


/** I find user-written schemes (and my own schemes) too restrictive.  In my opinion, when you are exploring your data, the appearance doesn't matter too much.  And when you are preparing a graph for inclusion in a paper, it should be fully customized. **

That said, I like to work with a monochrome scheme and add color only where I want it -- this is just personal preference */


** find and install the s1mono scheme **

findit s1mono
set scheme s1mono




*******
*****
**
* Demonstrating Graphics Options
**
*****
*******

** Start with a basic scatterplot **

twoway scatter hs_deg uninsured_pct


** That's pretty much unreadable because of how much data we have, so let's reduce the data by taking a random 1/10th of the observations **

gen random = uniform()
gen subset = 1 if random<0.10

twoway scatter hs_deg uninsured_pct if subset==1


/* This illustrates a useful trick--you can always use subsets of the data in graphs using the "if" command.  We can plot only Virginia's counties, or all counties that have high poverty rates

Normal if commands apply: 
	== is equal to 
	!= is not equal to 
	>< greater than or less than
	>= greater than or equal to
*/

twoway scatter hs_deg uninsured_pct if state=="Virginia"

twoway scatter hs_deg uninsured_pct if poverty>=20


** Changing marker symbols using msymbol 
		* subsets with if before the comma
		* options always after the comma

twoway scatter hs_deg uninsured_pct if subset==1, msymbol(Oh)


** Change marker colors and symbols with mcolor and msymbol 
		** To see available markers, install the showmarkers package with the command -findit showmarkers- 
		** use the command (remove the dashes) -showmarkers, over(msymbol)-

twoway scatter hs_deg uninsured_pct if subset==1, msymbol(+) mcolor(dkorange)


** Editing axis titles & editing the angle of tick labels **

twoway scatter hs_deg uninsured_pct if subset==1, msymbol(Oh) mcolor(dkorange) ytitle("Population with a High School Degree (%)") xtitle("Uninsured Population (%)") ylabel( , angle(horizontal))


** Adding a main title and changing the size of the axis titles **

twoway scatter hs_deg uninsured_pct if subset==1, msymbol(Oh) mcolor(dkorange) ytitle("Population with a High School Degree (%)") xtitle("Uninsured Population (%)", size(huge)) ylabel( , angle(horizontal)) title("Our First Graph")


** There may be situations where you want to include the full scale of the graph -- this is easy enough by using yscale and the sub-option "range."  We also need to specify some labels or it won't look very good.  -ylabel(0(10)100)- tells Stata to start at 0 and include labels every 10 units until it reaches 100  **

twoway scatter hs_deg uninsured_pct if subset==1, msymbol(Oh) mcolor(dkorange) yscale(range(0 100)) ylabel(0(10)100, angle(horizontal))



/*  Additional Options for Twoway Graphs 

We will cover more options as we go.  Some options to be aware of:

	-Adding reference lines: -xline(20)- will add a vertical line at x=20
	
	-Changing marker size: -msize(small)- or -msize(medlarge)- 
	
	-line width: -lwidth(thick)-
	
	-specifying the angle of tick labels: -ylabel(,angle(45))- or -xlabel(,angle(60))-
	
	-Minor tick marks: -xmtick(5 15 25)- will put small ticks ("m" stands for minor here) on the x-axis at 5, 15 and 25.
	
	-Minor tick marks with labels: -xmlabel(5 15 25)- will put small tick marks plus labels
	
	-Specifying major tick marks in greater detail.  Can literally do anything you want: ylabel(60 65(3)86 91 97)
	
	-Changing the outline color and fill color of markers independently: -msymbol(O) mlcolor(dkorange) mfcolor(dknavy)- specifies a circular marker with a dark orange outline and a dark navy fill.
	
	-Note: gs1 through gs15 are grayscale colors -- gs1 being darkest before black.
*/








*******
*****
**
* Histograms and Density Plots
**
*****
*******

/* **Standard use is to visualize the distribution of a single variable
	
		-As noted, can also be useful for inferences
*/

** Default is to draw the histogram as a density; sometimes a better option is to use frequency option---note the y axis **

hist poverty, frequency


** Stata's algorithms choose the "ideal" number of bins so you generally shouldn't mess around with them unless you have good reason.  We can also change the width to completely change the look of the graph **

hist poverty, frequency bin(50)

hist poverty, frequency barwidth(1)


/* **Altering the colors of the bars
		-color() changes fill AND outline colors
		-fcolor() changes the fill color
		-lcolor() changes the outline color
		-fintensity() changes the fill intensity
		-lpattern and lstyle allow further customization
*/

hist poverty, frequency barwidth(1) fcolor(gs8) lcolor(edkblue) 


** Axis options are the same as before - you can turn an axis title off by doing -ytitle("")-**

hist poverty, frequency barwidth(1) fcolor(gs8) lcolor(edkblue) xtitle("Percent Below Poverty Line") ylabel(,angle(horizontal)) ytitle("")


** Turning the bins into spikes by changing the barwidth **

hist poverty, frequency barwidth(0.05)


** Here is a clean style of thin boxes with a smaller sample.  Here we shrink the sample to 47 random cases **

gen subset2 = 1 if random<0.015

hist poverty if subset2==1, frequency width(1) barwidth(0.3) fcolor(white) lcolor(gs4) xtitle("Percent Below Poverty Line") ylabel(,angle(horizontal)) title("Frequency of Poverty Levels, 47 Counties")


** Some people prefer kernel density plots to histograms.  These are generated using the default Epanechnikov kernel function, but that can be changed **

kdensity poverty


** Here we can change the bandwidth, but generally you shouldn't.  The great thing about density plots is that you can nicely display several of them.  Here we subset by the percentage of high school graduates in a county and graph each group's poverty distribution using twoway kdensity **

gen hs = 0 if hs_deg<75
replace hs = 1 if hs_deg>=75 & hs_deg<90
replace hs = 2 if hs_deg>=90


** Note that we are drawing three graphs and laying them on top of one another -- the "||" means that we are starting another graph at that point in the command **

twoway kdensity poverty if hs==2 || kdensity poverty if hs==1 || kdensity poverty if hs==0


/* ** Can you tell those lines apart?  

I can't.  Here's a grayscale version.  We could easily make it color too, with lcolor instead of lpattern.  There is a theory here in the choice of longdash and dot -- they are very, very different from each other, and can both be easily distinguished from the solid line.  Colors are better, but many journals won't publish color graphics.

Note that each graph has it's own comma, with options following it.
*/

twoway kdensity poverty if hs==2, lpattern(solid) || kdensity poverty if hs==1, lpattern(longdash) || kdensity poverty if hs==0, lpattern(dot)


** Now we need to clean up the legend, among other things.  The legend commands only have to be specified once in the overall command **

twoway kdensity poverty if hs==2, lpattern(solid) || kdensity poverty if hs==1, lpattern(longdash) || kdensity poverty if hs==0, lpattern(dot) legend(label(1 "H.S. Degree 90%+") label(2 "H.S. Degree 75-90%") label(3 "H.S. Degree below 75%")) xtitle(Percent below Poverty Line) ytitle(Density) 


** Finally, we can specify that the legend be a single column, and it's location **

twoway kdensity poverty if hs==2, lpattern(solid) || kdensity poverty if hs==1, lpattern(longdash) || kdensity poverty if hs==0, lpattern(dot) legend(cols(1) label(1 "H.S. Degree 90%+") label(2 "H.S. Degree 75-90%") label(3 "H.S. Degree below 75%") position(9)) xtitle(Percent below Poverty Line) ytitle(Density) 


** Let's use the area inside the graph more wisely and put the legend in the upper-right corner.  Specifying -ring(0)- tells Stata the legend will be in the plot region; -bplacement(neast)- tells Stata to put it in the northeast corner **

twoway kdensity poverty if hs==2, lpattern(solid) || kdensity poverty if hs==1, lpattern(longdash) || kdensity poverty if hs==0, lpattern(dot) legend(cols(1) label(1 "H.S. Degree 90%+") label(2 "H.S. Degree 75-90%") label(3 "H.S. Degree below 75%") ring(0) bplacement(neast)) xtitle(Percent below Poverty Line) ytitle(Density) 









*******
*****
**
* Bar Graphs
**
*****
*******

** Bar graphs are probably overused, generally.  But they can still be useful. **

** Let's subset the sample so that we can look at 5 states **

gen subset3 = 1 if state=="Virginia" || state=="North Carolina" || state=="West Virginia" || state=="Kentucky" || state=="Maryland"

graph bar no_plumbing if subset3==1, over(state) horizontal


** Be careful with this graph - these are NOT the percentage of households without plumbing in each state.  Rather, this is the mean of Kentucky's county percentages.  When they are aggregated, they are NOT population-weighted.  This will work for illustration, but be cautious **

** We can also use medians instead of means; fixing labels **

graph bar (median) no_plumbing if subset3==1, over(state) horizontal ytitle("Households without Indoor Plumbing (%), County Medians")


** Perhaps we are interested about insurance coverage for different groups in each state; note the slightly different syntax for specifying colors of the bars compared to the scatterplots earlier **

graph bar no_plumbing no_kitchen if subset3==1, over(state) bargap(5) horizontal bar(1, color(maroon) fintensity(inten70)) bar(2, color(gs9)) legend(cols(1) order(1 "Pct of Homes without Indoor Plumbing" 2 "Pct of Homes without Kitchen Facilities"))


/*  ** A useful trick if you're not satisfied with Stata's color options:
	
	You can enter the RGB numbers for any color directly into a graph command.  Go to https://kuler.adobe.com/create/color-wheel/ and choose any color you like.  Then take the RGB colors and plug in as follows
*/

graph bar no_plumbing no_kitchen if subset3==1, over(state) bargap(5) horizontal bar(1, color(122 150 255) fintensity(inten70)) bar(2, color(gs9)) legend(cols(1) order(1 "Pct of Homes without Indoor Plumbing" 2 "Pct of Homes without Kitchen Facilities"))


** Adding error bars to show uncertainty in our estimates -- this might be a useful alternative to a table full of t-tests.  To do this, we have to collapse our data **

preserve
collapse (mean) mean_un1 = uninsured_under18 mean_un0 = uninsured_pct (sd) sd_un1 = uninsured_under18 sd_un0 = uninsured_pct, by(state)

gen ub1 = mean_un1 + (1*sd_un1)
gen lb1 = mean_un1 - (1*sd_un1)
gen ub0 = mean_un0 + (1*sd_un0)
gen lb0 = mean_un0 - (1*sd_un0)

keep if state=="Virginia" || state=="Utah" || state=="Connecticut" || state=="New Mexico"

gen state_id=_n
reshape long mean_un sd_un ub lb, i(state_id state) j(group)

gen group_id = state_id*3 if group==0
replace group_id = (state_id*3)+1 if group==1

twoway (bar mean_un group_id, base(0))

twoway (bar mean_un group_id, base(0))(rcap ub lb group_id)


** A nice grayscale graph **

twoway bar mean_un group_id if group==0, base(0) horizontal lcolor(gs2) fcolor(gs13) lwidth(0.2) || bar mean_un group_id if group==1, base(0) horizontal lcolor(gs2) fcolor(gs7) lwidth(0.2) || rcap ub lb group_id, horizontal lcolor(black) lwidth(0.4) ylabel(3.5 "Connecticut" 6.5 "New Mexico" 9.5 "Utah" 12.5 "Virginia", angle(horizontal)) ytitle("") legend(cols(1) order(2 "Under-18 Uninsured, Percent" 1 "Total Uninsured, Percent" 3 "1 Std. Deviation Interval")) 


** A color version **

twoway bar mean_un group_id if group==0, base(0) horizontal bcolor(gs7) || bar mean_un group_id if group==1, base(0) horizontal bcolor(gs2) || rcap ub lb group_id, horizontal lcolor(maroon) lwidth(0.4) ylabel(3.5 "Connecticut" 6.5 "New Mexico" 9.5 "Utah" 12.5 "Virginia", angle(horizontal)) ytitle("") legend(cols(1) order(2 "Under-18 Uninsured, Percent" 1 "Total Uninsured, Percent" 3 "1 Std. Deviation Interval")) 

** One note on that last graph -- we probably ought to make the order of the states meaningful; perhaps order them by percentage uninsured, for instance **


** Restore the data to where we were when we did -preserve- ** 

restore


/* ** Additional useful bar graph options

		-Group bars: -over(varname)- allows you to group bars by country, state, etc. as we did above
		
		-Repeat the same graph for each member of a group: -by(varlist)- makes separate graphs for different groups.  We could have used this to generate a graph for Utah, one for Virginia, etc and they would have all been in a single graphic.
		
	** Note: the options for -graph bar- and -twoway bar- are different.  All the options for the scatterplots above are applicable to -twoway bar-.  
*/








*******
*****
**
* Dot Plots and Re-Purposed Scatterplots
**
*****
*******

/* ** 
	There are many good reasons to use dotplots, particularly in place of bar graphs.  They often communicate the same information but do so in a cleaner fashion; see Tufte's advice on the "data-ink ratio."  In Stata, they have the added advantage of being a bit easier to work with in many cases.

	Imagine you want to illustrate the differences between insurance rates across 50 states, but you want to incorporate a measure of uncertainty (i.e. standard deviations or 95% confidence intervals).  You COULD present this in a table, with 50 means and their 95% confidence intervals.  Or you could present a series of t-tests.  But a cleaner way to present A LOT of data is in a dotplot  
*/

** Generate state means and standard deviations, aggregating the county averages -- again, note that these are not properly population-weighted (for illustration only) **

bysort state: egen uninsured_mean = mean(uninsured_pct)

bysort state: egen uninsured_sd = sd(uninsured_pct)

gen ub_80 = uninsured_mean + (uninsured_sd*1.28)
gen lb_80 = uninsured_mean - (uninsured_sd*1.28)


** Graphs the mean of county uninsured rates for each state, with error bars **

twoway dot uninsured_mean state_id, horizontal || rcap ub_80 lb_80 state_id, horizontal 


** Let's order this by rates of uninsured -- so that high insurance states are at the top and low insurance states are at the bottom.  We also want to have labels with state abbreviations, which requires a little work. **

drop if state=="District of Columbia"

sort uninsured_mean
egen rank = group(uninsured_mean)

bysort state_id rank: gen rank_within=_n

sort rank_within rank

label define lab_x 1 "MA"

foreach i of numlist 2/51{
	local x = state_abb[`i']
	label define lab_x `i' "`x'", add
}

label value rank lab_x

label var rank lab_x

** Now we can put meaningful labels in our dotplot **

twoway dot uninsured_mean rank, horizontal ylabel(1(1)50, valuelabel angle(horizontal)) || rcap ub_80 lb_80 rank, horizontal 


** That's a little crowded, so we can either plot these separately or separate them using -by-.  The simpler option will be to graph them separately **

twoway dot uninsured_mean rank if rank<26, horizontal ylabel(1(1)25, valuelabel angle(horizontal)) || rcap ub_80 lb_80 rank if rank<26, horizontal 


** A cleaned up version **

twoway dot uninsured_mean rank if rank<26, horizontal ylabel(1(1)25, valuelabel angle(horizontal)) ytitle("") xtitle("Percentage Uninsured, Mean of County Totals") legend(off) title("Percentage Uninsured and 90% Confidence Intervals") || rcap ub_80 lb_80 rank if rank<26, horizontal 


** If you hate the dots, you can reconfigure as a scatterplot with minor adjustments **

twoway scatter rank uninsured_mean if rank<26, ylabel(1(1)25, valuelabel angle(horizontal)) ytitle("") xtitle("Percentage Uninsured, Mean of County Totals") legend(off) title("Percentage Uninsured and 90% Confidence Intervals") || rcap ub_80 lb_80 rank if rank<26, horizontal


/* ** ALTERNATIVE: The start of an approach with -by-

	gen rank_dummy = 1 if rank>25
	replace rank_dummy = 0 if rank<26
	gen new_rank = rank if rank_dummy==0
	replace new_rank = rank - 25 if rank_dummy==1


	twoway dot uninsured_mean new_rank, horizontal ylabel(1(1)25, valuelabel angle(horizontal)) by(rank_dummy) || rcap ub_80 lb_80 new_rank, horizontal 

*/


** Our last graph made all these states seem pretty similar, so let's investigate whether there are within-state differences across counties.  We can take the dot plot a step further to do this (I noted an example where this can be helpful at the outset of the workshop). **


** A very basic version to illustrate the approach -- this is just two layered scatterplots **

twoway scatter rank uninsured_pct if rank>39 & rank_within<15  || scatter rank uninsured_mean if rank>39, mcolor(dkorange) 


** A cleaned up version. I like a small dotted line for these types of plots **

twoway scatter rank uninsured_pct if rank>39 & rank_within<15, msymbol(Oh) mcolor(edkblue) msize(vlarge) ylabel(40(1)50, valuelabel angle(horizontal)) ytitle("") xtitle("Percentage Uninsured, by County") yline(40(1)50, lstyle(dot)) || scatter rank uninsured_mean if rank>39, msymbol(Oh) mcolor(dkorange) msize(vlarge) mlwidth(medthick) legend(order(1 "County Averages" 2 "State Average"))


** One valuable option in scatterplots is labeling an individual point.  Here is the same basic version above with a labeled point. You have to know the coordinates to do this for a single point.  -place(sw)- specifies the placement of the text relative to the point, southwest in this case. 49 is New Mexico's value on rank; 41.2 is the county of interest's value on uninsured_pct **


***
***
***
** Fix it on the fly **

list rank_within state county_name if state=="New Mexico"
***
***
***


twoway scatter rank uninsured_pct if rank>39 & rank_within<25 & rank_within>10  || scatter rank uninsured_mean if rank>39, mcolor(dkorange) text(49 41.2 "McKinley Cty, NM", place(sw) size(small))


/* ** We can make a variety of fine adjustments using:
		-textbox_options-
		-margin()-
		-just()-
		-width()-
	and so on
*/







*******
*****
**
* Various Inferential Plots
**
*****
*******

/*
		** Graph Types **
			-Split scatterplots
			-Scatterplots with lines of best fit
			-Scatterplots with varying bubble size
			-Coefficient dot plots

*/

** Imagine you have a scatterplot showing a relationship between two variables, but you want to investigate whether that relationship is the same across two subgroups.  There are two possible approaches here. **

gen west=.
replace west=0 if state=="Kentucky" | state=="West Virginia" | state=="Maryland" | state=="Virginia" | state=="North Carolina"

replace west=1 if state=="Wyoming" | state=="Idaho" | state=="Montana" | state=="Nevada" | state=="Colorado" | state=="Utah" | state=="New Mexico" | state=="Arizona"


** Our basic scatterplot **

scatter hs_deg uninsured_pct if west!=.


** Subsetting using -by- **

scatter hs_deg uninsured_pct if west!=., by(west)


** Subsetting with different colors **

scatter hs_deg uninsured_pct if west==0, msymbol(Oh) mcolor(dkorange) || scatter hs_deg uninsured_pct if west==1, msymbol(Oh) mcolor(edkblue)

scatter hs_deg uninsured_pct if west==0, msymbol(Oh) mcolor(dkorange) || lfit hs_deg uninsured_pct if west==0, lcolor(dkorange) || scatter hs_deg uninsured_pct if west==1, msymbol(Oh) mcolor(edkblue) || lfit hs_deg uninsured_pct if west==1, lcolor(edkblue)


/* ** Lines of Best Fit

		There are several types of best-fit lines you can use in the twoway scatter commands: lfit (line); qfit (quadratic); lfitci (line with confidence intervals); qfitci (quadratic fit with confidence intervals); mspline (median-spline); and so on. 

		Probably the most useful type of graph of this variety is lowess (locally weighted scatterplot smoothing) -- allows you to see local variation in the relationship, look for non-linearities, etc.
*/

lowess bach_deg homes_1950s


/* ** Other useful diagnostic plots

		-Scatterplot matrix: -graph matrix variable_list- generates a scatterplot for each pair of variables in variable_list.  
*/


** Scatterplots with varying-size markers can be useful for showing relationships among three variables **

twoway scatter poverty uninsured_pct [weight=total_hh] if state=="Utah" | state=="Colorado" | state=="Arizona", msymbol(Oh)




/*  ** Coefficient Dot Plots

		-One of my favorite graphs
		
		-Probably the best way to present regression results, in 99% of cases
		
		-Can present lots of models in a compact space

	We've already seen a version of these when we did dot plots.  This is the same idea, but we want to run a set of regressions, extract the results, and plot them.
*/

** -findit coefplot- **

** A basic coefficient plot: -drop(_cons) drops the coefficient for the constant **

reg poverty hs_deg bach_deg english_home never_married, cluster(state)

estimates store m1

coefplot m1, drop(_cons)


** Specifying several models **

estimates clear

reg poverty hs_deg bach_deg, cluster(state)
est sto m1

reg poverty hs_deg bach_deg english_home, cluster(state)
est sto m2

reg poverty hs_deg bach_deg english_home never_married, cluster(state)
est sto m3

reg poverty hs_deg english_home never_married, cluster(state)
est sto m4

coefplot m1 m2 m3 m4, drop(_cons) levels(95) ciopts(recast(rcap)) xline(0)


** With Colors for each model **

coefplot (m1, mcolor(edkblue) ciopts(lcolor(edkblue)))(m2, mcolor(dkorange) ciopts(lcolor(dkorange)))(m3, mcolor(dkgreen) ciopts(lcolor(dkgreen)))(m4, mcolor(maroon) ciopts(lcolor(maroon))), drop(_cons) msymbol(O) xline(0) 


** If we rename those models the legend works out better.  But we can also edit the legend ourselves using labels **

coefplot (m1, levels(90) mcolor(edkblue) ciopts(lcolor(edkblue)) label(Model 1))(m2, mcolor(dkorange) ciopts(lcolor(dkorange)) label(Model 2))(m3, mcolor(dkgreen) ciopts(lcolor(dkgreen)) label(Model 3))(m4, mcolor(maroon) ciopts(lcolor(maroon)) label(Model 4)), drop(_cons) msymbol(O) xline(0) legend(cols(4)) 


** Splitting the models into two coefficient plots -- this is particularly useful if there are two types of models we want to run.  For instance, if we want OLS and logit models side by side, or models with and without state fixed effects side by side **

estimates clear

reg poverty hs_deg bach_deg if subset3!=.
est sto m1

reg poverty hs_deg bach_deg english_home if subset3!=.
est sto m2

reg poverty hs_deg bach_deg english_home never_married if subset3!=.
est sto m3

reg poverty hs_deg english_home never_married if subset3!=.
est sto m4

** Fixed effects estimates **

areg poverty hs_deg bach_deg if subset3!=., absorb(state)
est sto m5

areg poverty hs_deg bach_deg english_home if subset3!=., absorb(state)
est sto m6

areg poverty hs_deg bach_deg english_home never_married if subset3!=., absorb(state)
est sto m7

areg poverty hs_deg english_home never_married if subset3!=., absorb(state) 
est sto m8

coefplot (m1, levels(90) mcolor(edkblue) ciopts(lcolor(edkblue)) label(Model 1))(m2, mcolor(dkorange) ciopts(lcolor(dkorange)) label(Model 2))(m3, mcolor(dkgreen) ciopts(lcolor(dkgreen)) label(Model 3))(m4, mcolor(maroon) ciopts(lcolor(maroon)) label(Model 4)), bylabel(Standard Models) || (m5, levels(90) mcolor(edkblue) ciopts(lcolor(edkblue)) label(Model 1))(m6, mcolor(dkorange) ciopts(lcolor(dkorange)) label(Model 2))(m7, mcolor(dkgreen) ciopts(lcolor(dkgreen)) label(Model 3))(m8, mcolor(maroon) ciopts(lcolor(maroon)) label(Model 4)), bylabel(Fixed Effect Models) ||, drop(_cons) msymbol(O) xline(0) legend(cols(4))


** I actually prefer to present a series of models focused on one independent variable of interest.  Imagine we want to run the same regression predicting poverty, but we want to run it 50 times, each time dropping one state from the model.  This might be useful to check for the effect of outlier states. **

* Let's pretend the independent variable we care about most is the employment rate.  Our base model is:

estimates clear

reg poverty hs_deg bach_deg english_home never_married employment_rate, cluster(state)
est sto base

** Loop through state id's, running regressions and saving results **

foreach i of numlist 1/35 {
	quietly areg poverty hs_enrollment hs_deg bach_deg english_home never_married employment_rate if state_id!=`i', absorb(state) cluster(state)
	est sto m`i'
}

coefplot base m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12 m13 m14 m15 m16 m17 m18 m19 m20 m21 m22 m23 m24 m25 m26 m27 m28 m29 m30 m31 m32 m33 m34 m35, drop(_cons hs_deg bach_deg english_home never_married employment_rate) msymbol(O) mcolor(black) ciopts(lcolor(black) recast(rcap)) xline(0) legend(off) xscale(range(-.15 0.05)) xlabel(-0.15 -.10 -.05 0 .05) ytitle("Leave-One-Out Models", angle(horizontal)) ylabel("") title("Employment Rate's Effect on Poverty") subtitle("Point Estimates and 95% Confidence Intervals")


/* ** We can also plot the results from logit models, multinomial logit, and any other estimation you can run in Stata. 
	
	-One nice thing is that coefplot allows you to plot the log-odds, odds ratios, average marginal effects and other substantive effects of interest
*/


** An example with odds ratios **

estimates clear

gen high_poverty = 0
replace high_poverty = 1 if poverty>18
quietly tab state, gen(state_dummy)

quietly logit high_poverty hs_deg bach_deg state_dummy*
est sto m1

quietly logit high_poverty hs_deg bach_deg english_home state_dummy*
est sto m2

quietly logit high_poverty hs_deg bach_deg english_home never_married state_dummy*
est sto m3

quietly logit high_poverty hs_deg english_home never_married state_dummy*
est sto m4

coefplot m1 m2 m3 m4, drop(_cons state_dummy*) eform xline(1) mcolor(black) msymbol(O) ciopts(lcolor(black)) legend(off) title(Logit Models of Poverty)









*******
*****
**
* Plotting Predicted Probabilities in Ordered and Multinomial Logit Models
**
*****
*******



/*  ** Ordered logit and multinomial logit

		-Create problems of presenting graphically
*/

findit spost9_ado


** Create an ordered variable for poverty **

gen pov_cat = 0 if poverty<10
replace pov_cat = 1 if poverty>=10 & poverty<20
replace pov_cat = 2 if poverty>=20 & poverty<30
replace pov_cat = 3 if poverty>30


** Run ordered logit regression -- this model predicts the likelihood of a county being in one of four categories **

ologit pov_cat hs_deg bach_deg


** Use -prgen- to produce predicted probabilities of being in each category of poverty across different values of hs_deg.  We set the other variables in the model (bach_deg) at their mean with -rest(mean)- and we tell Stata to vary hs_deg over the range 50 to 100 (i.e. from 60% to 100% of the population with a high school degree).  It generates new variables of povp0 through povp3 (for our 4 categories of poverty), with 10 observations each (corresponding to 10 different levels of hs_deg--we can specify any number we want here, but more is not always better. **

prgen hs_deg, rest(mean) from(60) to(100) generate(pov) ncases(10)


** After looking at the results, plot them.  Note that povx is simply the value of hs_deg at which we are predicting the probability of pov_cat in each observation **

graph twoway connected povp0 povp1 povp2 povp3 povx, scheme(s2color)

graph twoway connected povp0 povp1 povp2 povp3 povx, scheme(s2color) legend(order(1 "Poverty Rate Under 10%" 2 "Poverty Rate 10-20%" 3 "Poverty Rate 20-30%" 4 "Poverty Rate Above 30%")) ytitle("Probability of Category Outcome") xtitle("High School Degree, Percent of Population")


*/ 	** This example is a little confusing because "poverty category" is not something we typically think about.  Poverty rate, yes, but not "poverty category."  

	But the graph still makes the relationships clear.  For counties with the lowest percentages of high school degrees, they are most likely to be in the 20-30% poverty range.  The likelihood of being in the highest two categories of poverty (20-30% and 30%+) are both monotonically decreasing with higher percentages of high school degrees.  
	
	The red bar that forms a big hump (poverty rate between 10 and 20%) in the middle shows exactly what we would expect.  The counties with the lowest percentage of high school degrees don't fall into this category very often (20% of the time)--but the counties with low to medium percentages of high school degrees do.  As you increase the percentage of people with high school degrees in the population, the likelihood of being in the lowest poverty category comes to dominate, to the exclusion of all others.
	
	*mlogit: we won't present an example with multinomial logit, but the approach is literally identical
*/









*******
*****
**
* Time-series Line Plots
**
*****
*******


clear
use "housing_ts.dta", clear

set scheme s1mono

sort state_id year quarter
by state_id: gen time_period=_n

** Here is a basic line graph of one state to start **
twoway line house_price_index time_period if state=="Virginia"

** Notice that because we have data on all 50 states, we have to use "if" commands to choose the states we want to graph.  We can also overlay multiple line graphs **

twoway line house_price_index time_period if state=="Virginia" || line house_price_index time_period if state=="California"

** Let's do something more interesting with this data.  We've seen that California experienced a deeper housing market crisis than Virginia.  We might imagine that states that experienced oil booms during the crisis experienced a less severe drop in house prices.  I've coded a variable to indicate whether a state had a large decrease, a large increase or no significant change in oil and gas production during the crisis.

** oilgas = 0 if the state experienced a large decline in oil/gas production during 2005-2009 (AK, CA, AL, MI, FL, etc)
** oilgas = 1 if the state experienced neither a large decline nor a large increase
** oilgas = 2 if the state experienced a large increase in oil/gas production during 2005-2009 (UT, ND, LA, TX, etc)

collapse (mean) house_price_index year quarter, by(oilgas time_period)  // aggregates the data by category and time period.  We now have a time series for each of our three categories


** Note: You probably DON'T want a graph like this **

twoway line house_price_index time_period, by(oilgas)


** A basic line graph **

twoway line house_price_index time_period if oilgas==0 || line house_price_index time_period if oilgas==1 || line house_price_index time_period if oilgas==2, ytitle("Home Price Index (1991 = 100)") xtitle("Year")  


** Cleaning it up a bit **

twoway line house_price_index time_period if oilgas==0 || line house_price_index time_period if oilgas==1 || line house_price_index time_period if oilgas==2, ytitle("Home Price Index (1991 = 100)") xtitle("Year")  ylabel(,angle(horizontal)) xlabel(0.1 "1990" 18.5 "1995" 38.5 "2000" 58.5 "2005" 78.5 "2010")


** This graph is better but the legend is still meaningless.  And the shades of gray are hard to distinguish.  Here is a color option **

twoway line house_price_index time_period if oilgas==0, lwidth(0.5) lcolor(blue) || line house_price_index time_period if oilgas==1, lwidth(0.5) lcolor(green) || line house_price_index time_period if oilgas==2, lwidth(0.5) lcolor(dkorange) ytitle("Home Price Index (1991 = 100)") xtitle("Year") xlabel(0.1 "1990" 18.5 "1995" 38.5 "2000" 58.5 "2005" 78.5 "2010") ylabel(,angle(horizontal)) legend(cols(1) label(1 "States with Reduced Oil Production") label(2 "States with No Change in Oil Production") label(3 "States with Increased Oil Production"))


** And a fully grayscale option **

twoway line house_price_index time_period if oilgas==0, lwidth(0.5) || line house_price_index time_period if oilgas==1, lwidth(0.5) lpattern(longdash) || line house_price_index time_period if oilgas==2, lwidth(0.5) lpattern(dot) ytitle("Home Price Index (1991 = 100)") xtitle("Year") xlabel(0.1 "1990" 18.5 "1995" 38.5 "2000" 58.5 "2005" 78.5 "2010") ylabel(,angle(horizontal)) legend(cols(1) label(1 "States with Reduced Oil Production") label(2 "States with No Change in Oil Production") label(3 "States with Increased Oil Production"))


** Finally, we might consider reducing the time series somewhat, to focus attention on the years we actually care about.  This is easily done with a second "if" command

twoway line house_price_index time_period if oilgas==0 & year>1999, lwidth(0.5) || line house_price_index time_period if oilgas==1 & year>1999, lwidth(0.5) lpattern(longdash) || line house_price_index time_period if oilgas==2 & year>1999, lwidth(0.5) lpattern(dot) ytitle("Home Price Index (1991 = 100)") xtitle("Year") xlabel(38.5 "2000" 58.5 "2005" 78.5 "2010") ylabel(,angle(horizontal)) legend(cols(1) label(1 "States with Reduced Oil Production") label(2 "States with No Change in Oil Production") label(3 "States with Increased Oil Production"))


** If you are tired of line graphs, you can plot these time series with an area graph.  We can use all the same options as in the last graph, though I don't show them here. **

twoway area house_price_index time_period if oilgas==0 

twoway area house_price_index time_period if oilgas==0 || area house_price_index time_period if oilgas==1

twoway area house_price_index time_period if oilgas==0 || line house_price_index time_period if oilgas==1, lcolor(dknavy)


/*  ** One last option that can be useful -- specifying two different axes, if two of the variables you want to plot are on different scales.
		-Consider the problem of a house price index that varies from 100 to 250, and a stock market index or something similar, that is on a completely different scale
		
		**This section is not in the original do file**
*/

use "housing_ts.dta", clear

sort state_id year quarter
by state_id: gen time_period=_n

** Create a fake index for illustration **
gen random = uniform()
gen fake_index = (house_price_index * random)*100

collapse (mean) house_price_index fake_index year quarter, by(oilgas time_period)  
label var house_price_index "Home Price Index"
label var fake_index "Fake Index"

sum fake_index house_price_index

** Our fake index now varies from a couple thousand to well over 10,000, so it is roughly analogous to the stock market.  A normal time series plot has an obvious plot **

twoway line house_price_index fake_index time_period if oilgas==0 

twoway line house_price_index time_period if oilgas==0, yaxis(1) || line fake_index time_period if oilgas==1, yaxis(2) scheme(vg_s2c)


	

** A useful trick is to loop through all the states, making line graphs for each.  This is especially helpful if you want to examine the time-series for each state, to familiarize yourself with your data.  The best way to do this is to save each plot as a png file -- I've commented that out in the loop here, so you won't have 50 graphs saved on your hard disk **

clear
use "housing_ts.dta", clear

sort state_id year quarter
by state_id: gen time_period=_n

foreach i of numlist 1/50{
	twoway line house_price_index  time_period if state_id==`i'
	* graph export "D:\My Documents\Dropbox\Public\StatLab Workshops\Graphing with Stata\temp`i'.png", replace
}

** Now you can go flip through 50 state graphs and look for those that appear different, have strange discrepancies, etc. **






*******
*****
**
* THE END
**
*****
*******

/* 	** Final Notes

	- See the supplemental do file for box plots, violin plots, scatterplots with lines of best fit AND confidence intervals and a scatterplot matrix
	
	-See the slides provided for a few examples of graphics that are particularly illuminating or useful, but in different ways
	
*/




































