/*
*************
*************
********
******

UVA StatLab Workshop
Better Graphics with Stata
January 29, 2014

By: Brenton Peterson

Summary: Supplements the primary do file.  This do file creates a few graphs we did not have time for, but which may prove useful to some participants.

Specifics: box plots, violin plots, scatterplots with lines of best fit AND confidence intervals and scatterplot matrices

Note: This file goes into slightly less detail.  There are many, many options that can be specified for each of these graphs.  Check out the help pages for customizing them beyond what is done here; note that a lot of the standard commands like ylabel, horizontal, title, xtitle, etc etc. work here.  But there are some commands specific to these graphs that are worth investigating.

******
********
*************
*************
*/


** Set working directory to wherever you extracted the workshop files **
cd "\Better Graphics in Stata"


** Load up data, set scheme **
use "county_2010.dta", clear
set scheme s1mono


** Reduce the amount of data we have **
gen random = uniform()
gen subset = 1 if random<0.10
keep if subset==1




*******
*****
**
* Scatterplot Matrices
**
*****
*******


/* ** Scatterplot matrices can be useful for exploring your data
		
		-Not really useful for other things
		-Please do not put these in a paper, except under exceptional circumstances
*/

** A first cut**

graph matrix poverty bach_deg hs_deg english_home employment_rate


** All our normal options for scatterplots work here -- msymbol, mcolor, axis labels, etc **

graph matrix poverty bach_deg hs_deg english_home employment_rate, msymbol(+)


** One useful option is -half- **

graph matrix poverty bach_deg hs_deg employment_rate, msymbol(+) half


** Sadly, there is no way to include lines of best fit for each scatterplot, so you have to brute force a similar matrix.  See below. Note that this saves several graphs to your hard drive and then stitches them together using -graph combine-. Note that -xscale(alt)= tells Stata to put the xaxis on the top of the graph, not the bottom.  This becomes important when we stitch things with -graph combine-**

scatter poverty bach_deg || lfit poverty bach_deg, legend(off) xscale(alt)
graph save "sc1.gph", replace
scatter poverty hs_deg || lfit poverty hs_deg, legend(off) xscale(alt)
graph save "sc2.gph", replace
scatter poverty employment_rate || lfit poverty employment_rate, legend(off) xscale(alt)
graph save "sc3.gph", replace
scatter bach_deg hs_deg || lfit bach_deg hs_deg, legend(off) xscale(alt)
graph save "sc4.gph", replace
scatter bach_deg employment_rate || lfit bach_deg employment_rate, legend(off) xscale(alt)
graph save "sc5.gph", replace
scatter hs_deg employment_rate || lfit hs_deg employment_rate, legend(off) xscale(alt)
graph save "sc6.gph", replace


** A first cut **

graph combine "sc1.gph" "sc2.gph" "sc3.gph" "sc4.gph" "sc5.gph" "sc6.gph"


** This isn't quite right, but it's getting closer; there are options in -graph combine- to allow you to combine axes (ycommon and xcommon), among other things, which might get the job done. **

graph combine "sc1.gph" "sc2.gph" "sc3.gph" "sc4.gph" "sc5.gph" "sc6.gph", holes(2 3 6)







*******
*****
**
* Box Plots and Violin Plots
**
*****
*******

use "county_2010.dta", clear


** Make a series of box plots for each state **

graph box english_home, over(state) horizontal


** That's a little messy, so let's compare just SW states and upper midwest/upper plains states **

gen reg_comp = 1 if state=="California" | state=="Arizona" | state=="Utah" | state=="Nevada" | state=="New Mexico" | state=="Colorado"

replace reg_comp = 0 if state=="Minnesota" | state=="Wisconsin" | state=="North Dakota" | state=="South Dakota" | state=="Iowa"

graph box english_home if reg_comp!=., over(state) horizontal


** It would be a little nicer if we could group them by region.  We can do this with -by- but that creates two separate graphs and puts them side-by-side.  It will look nicer if we specify an order in which to plot them.  Let's divide them by region and put them in order of their mean within regions.   The option -, sort(1)- tells Stata to sort the box plots by the median value of english_home amongst the states.  Luckily this accomplishes the order that we want, since every SW state has a lower median than every MW/Plains state.  That won't always be the case.  But even so, we might want to more clearly delineate our two groups.  First, with just -sort **

** -nooutside- specifies that Stata should not include outlying values in the plot.  I prefer this; others don't. **

graph box english_home if reg_comp!=., over(state, sort(1)) horizontal nooutside 





/* ** Violin plots **

		Hat tip to Nick Winter, UVA Dept of Politics, who created this package

		Violin plots add an additional bit of information to the normal box plot by plotting a kernel density of the distribution around the boxplot
*/		

ssc install vioplot


** Basic syntax **

vioplot english_home

vioplot english_home if reg_comp!=., over(state) horizontal ylabel(, angle(horizontal))


** Let's just look at southwestern states and play with a few options **

vioplot english_home if reg_comp==1, over(state) horizontal ylabel(, angle(horizontal))


** -obs- puts the number of observations onto the graph, which could be useful information since our states have quite different numbers of counties/observations **

vioplot english_home if reg_comp==1, over(state) horizontal ylabel(, angle(horizontal)) obs 


** I think these graphs look quite a bit better in color **

vioplot english_home if reg_comp==1, over(state) horizontal ylabel(, angle(horizontal)) obs scheme(s2color)


** We can also choose all the colors we want manually **

vioplot english_home if reg_comp==1, over(state) horizontal ylabel(, angle(horizontal)) obs density(lcolor(edkblue) fcolor(edkblue) fintensity(inten60)) median(msymbol(D) msize(large)) line(lcolor(black)) 

vioplot english_home if reg_comp==1, over(state) horizontal ylabel(, angle(horizontal)) obs density(lcolor(edkblue) fcolor(edkblue) fintensity(inten60)) median(msymbol(D) msize(large)) line(lcolor(black)) xtitle("Percent of Homes that are English-Speaking")









*******
*****
**
* Graphing with confidence intervals
**
*****
*******


/* ** Scatterplots with lines of best fit and confidence intervals

		I don't personally find confidence intervals in scatterplots very useful.  But they have their place
*/

** Reduce the data **
gen random=uniform()
drop if random>0.10


** Our baseline plot and a first attempt with lfitci.  Note: you should specify lfitci as the first graph and scatter as the second, so that the confidence interval does not cover up your scatterplot's points **

twoway scatter hs_deg uninsured_pct 

twoway lfitci hs_deg uninsured_pct || scatter hs_deg uninsured_pct


** We can easily use 90 or 99% or any other confidence level intervals.  In some cases you might want to overlay 90 and 95% intervals to show the difference.  One way would be specify one CI as a shaded region as above and one CI as a set of lines using -ciplot(rline)- **

twoway lfitci hs_deg uninsured_pct, ciplot(rline) level(99) lcolor(maroon) || lfitci hs_deg uninsured_pct, level(90) || scatter hs_deg uninsured_pct, scheme(s2color)

** Let's fix the legend and some labels **

twoway lfitci hs_deg uninsured_pct, ciplot(rline) level(99) lcolor(maroon) || lfitci hs_deg uninsured_pct, level(90) || scatter hs_deg uninsured_pct, scheme(s2color) legend(order(1 "99% CI" 3 "90% CI")) xtitle("Uninsured Population, Percent") ytitle("Population with a High School Degree, Percent") ylabel(, angle(horizontal))


* And a version all in grayscale *

twoway lfitci hs_deg uninsured_pct, ciplot(rline) level(99) || lfitci hs_deg uninsured_pct, level(90) || scatter hs_deg uninsured_pct, legend(order(1 "99% CI" 3 "90% CI")) xtitle("Uninsured Population, Percent") ytitle("Population with a High School Degree, Percent") ylabel(, angle(horizontal))



* A grayscale version with a little bit of color *

twoway lfitci hs_deg uninsured_pct, ciplot(rline) level(99) lcolor(maroon) || lfitci hs_deg uninsured_pct, level(90) || scatter hs_deg uninsured_pct, legend(order(1 "99% CI" 3 "90% CI")) xtitle("Uninsured Population, Percent") ytitle("Population with a High School Degree, Percent") ylabel(, angle(horizontal))


** You're not restricted to linear best fit, though.  You can also use qfit with qfitci.  Unfortunately, while you can plot "lines" with mspline and mkspline, I'm not aware of a Stata routine that allows you to plot confidence intervals around them.  You'd have to do that manually, by creating variables encompassing the bounds of the confidence intervals.  Here is our same graph with qfit **

twoway qfitci hs_deg uninsured_pct, ciplot(rline) level(99) lcolor(maroon) || qfitci hs_deg uninsured_pct, level(90) || scatter hs_deg uninsured_pct, legend(order(1 "99% CI" 3 "90% CI")) xtitle("Uninsured Population, Percent") ytitle("Population with a High School Degree, Percent") ylabel(, angle(horizontal))


/* ** Confidence bands in time-series

	One place it might be nice to use a sort of confidence interval is in repeated cross-section data, where you have estimates of uncertainty that vary over time.  For instance, consider repeated public opinion polls.  We know that polls will vary over time, but if we were to plot the public's opinion of some issue over 10 years, we wouldn't have any sense of the uncertainty associated with those figures.  It would be difficult to know what represented a real shift in opinion and what represented noise.  We can plot confidence bands over time to illustrate this.
	
	We can also use this to compare two states' time series to illustrate when they are statistically indistinguishable from one another and when they are not.

	We'll use the housing price index for this purpose, and imagine that it is a series of ~90 repeated cross-sections.  This may be a bit convoluted, but the point is to illustrate the approach.
*/

use housing_ts.dta, clear


** Fabricate a measure of uncertainty that will be similar to most polls' sampling error of ~2.5% plus/minus.  We generate random numbers from a uniform distribution but we'll make them a bit bigger than 2.5 to better illustrate.  We'll use these as our 95% confidence interval.  In practice, you might have the standard error of a measure, so you'll have to multiply that standard error by 1.96 to get the same intervals. **

sort state_id year quarter
by state_id: gen time_period=_n
drop if time_period<21

keep if state=="California" | state=="Utah"

gen double CI = (6-3)*runiform() + 3

gen ub = house_price_index + CI
gen lb = house_price_index - CI

twoway line house_price_index ub lb time_period if state=="California"  

** An alternative using rspike **

twoway line house_price_index time_period if state=="California" || rspike ub lb time_period if state=="California"

** Now with both states and just the spikes for the confidence intervals **

twoway rspike ub lb time_period if state=="California" || rspike ub lb time_period if state=="Utah"

** Of course we would want to fix the legend, label the axes more clearly, and do some other things, but this should give you a sense of what is possible **





*******
*****
**
* THE END
**
*****
*******
















